@@ -1,3 +1,3 @@
 from .magnetic_flux import psi, derivatives
-from .model import compute_psi
+from .model import compute_psi, get_separatrix_coordinates
 from .parameters import *
